@@ -8,7 +8,7 @@ server URL, OFX protocol version, financial institution identifiers, client
 identifiers, etc.
 
 ``config/fi.cfg`` contains a database of these parameters, most conveniently
-accessed via ``scripts/ofx.py``.
+accessed via ``scripts/ofxget.py``.
 
 Using the configured ``OFXClient`` instance, make a request by calling the
 relevant method, e.g. ``OFXClient.request_statements()``.  Provide the password
@@ -71,6 +71,15 @@ from typing import (
 )
 
 
+# 3rd party libs
+try:
+    import requests
+
+    USE_REQUESTS = True
+except ImportError:
+    USE_REQUESTS = False
+
+
 # local imports
 from ofxtools.header import make_header
 from ofxtools.models.ofx import OFX
@@ -227,9 +236,7 @@ class OFXClient:
     # Stmt request
     bankid: Optional[str] = None
     brokerid: Optional[str] = None
-
-    # URL opener
-    url_opener: Optional[Callable] = None
+    persist_cookies: bool = True
 
     def __repr__(self) -> str:
         r = (
@@ -259,7 +266,7 @@ class OFXClient:
         bankid: Optional[str] = None,
         brokerid: Optional[str] = None,
         useragent: Optional[str] = None,
-        persist_cookies: bool = True,
+        persist_cookies: bool = None,
     ):
 
         self.url = url
@@ -278,6 +285,7 @@ class OFXClient:
             "bankid",
             "brokerid",
             "useragent",
+            "persist_cookies",
         ]:
             value = locals()[attr]
             if value is not None:
@@ -286,10 +294,9 @@ class OFXClient:
         if (not self.close_elements) and self.version >= 200:
             raise ValueError(f"OFX version {self.version} must close all tags")
 
-        if persist_cookies:
-            cj = http.cookiejar.CookieJar()
-            opener = urllib_request.build_opener(urllib_request.HTTPCookieProcessor(cj))
-            self.url_opener = opener.open
+        # Allow persistent cookies in case PROFRS sets cookies that are needed by
+        # subsequent STMTRQ or what have you.
+        self.cookiejar = http.cookiejar.CookieJar()
 
     @classproperty
     @classmethod
@@ -303,7 +310,7 @@ class OFXClient:
 
     @property
     def http_headers(self) -> Dict[str, str]:
-        """ Pass to urllib.request.urlopen() """
+        """Pass to urllib.request.urlopen()"""
         mimetype = "application/x-ofx"
         # Python libraries such as ``urllib.request`` and ``requests``
         # identify themselves in the ``User-Agent`` header,
@@ -330,6 +337,7 @@ class OFXClient:
         gen_newfileuid: bool = True,
         dryrun: bool = False,
         timeout: Optional[float] = None,
+        skip_profile: bool = False,
     ) -> BinaryIO:
         """
         Package and send OFX statement requests
@@ -337,7 +345,12 @@ class OFXClient:
         """
         if dryrun:
             url = ""
+            logger.info("Dry run for statement request")
+        elif skip_profile:
+            url = self.url
+            logger.info(f"Skipping profile request; using url='{url}'")
         else:
+            logger.info("Requesting OFX profile to extract service URLs")
             RqCls2url = self._get_service_urls(
                 timeout=timeout,
                 gen_newfileuid=gen_newfileuid,
@@ -349,6 +362,7 @@ class OFXClient:
             urls = set(RqCls2url.values())
             assert len(urls) == 1
             url = urls.pop()
+            logger.info(f"Received service url={url} from OFX profile response")
 
         logger.info(f"Creating statement requests for {requests}")
         # Group requests by type and pass to the appropriate *TRNRQ handler
@@ -583,12 +597,15 @@ class OFXClient:
         version: Optional[int] = None,
         gen_newfileuid: bool = True,
         timeout: Optional[float] = None,
+        skip_profile: bool = False,
     ) -> BinaryIO:
         """
         Package and send OFX account info requests (ACCTINFORQ)
         """
         if dryrun:
             url = ""
+        elif skip_profile:
+            url = self.url
         else:
             RqCls2url = self._get_service_urls(
                 timeout=timeout,
@@ -635,12 +652,15 @@ class OFXClient:
         gen_newfileuid: bool = True,
         dryrun: bool = False,
         timeout: Optional[float] = None,
+        skip_profile: bool = False,
     ) -> BinaryIO:
         """
         Request US federal income tax form 1099 (TAX1099RQ)
         """
         if dryrun:
             url = ""
+        elif skip_profile:
+            url = self.url
         else:
             RqCls2url = self._get_service_urls(
                 timeout=timeout,
@@ -683,7 +703,7 @@ class OFXClient:
         userid: Optional[str] = None,
         sesscookie: Optional[str] = None,
     ) -> SIGNONMSGSRQV1:
-        """ Construct SONRQ; package in SIGNONMSGSRQV1 """
+        """Construct SONRQ; package in SIGNONMSGSRQV1"""
         if self.org:
             fi: Optional[FI] = FI(org=self.org, fid=self.fid)
         else:
@@ -720,7 +740,7 @@ class OFXClient:
         dtend: Optional[datetime.datetime] = None,
         inctran: bool = True,
     ) -> STMTTRNRQ:
-        """ Construct STMTRQ; package in STMTTRNRQ """
+        """Construct STMTRQ; package in STMTTRNRQ"""
         acct = BANKACCTFROM(bankid=bankid, acctid=acctid, accttype=accttype)
         inctran_ = INCTRAN(dtstart=dtstart, dtend=dtend, include=inctran)
         stmtrq = STMTRQ(bankacctfrom=acct, inctran=inctran_)
@@ -735,7 +755,7 @@ class OFXClient:
         dtstart: Optional[datetime.datetime] = None,
         dtend: Optional[datetime.datetime] = None,
     ) -> STMTENDTRNRQ:
-        """ Construct STMTENDRQ; package in STMTENDTRNRQ """
+        """Construct STMTENDRQ; package in STMTENDTRNRQ"""
         acct = BANKACCTFROM(bankid=bankid, acctid=acctid, accttype=accttype)
         stmtrq = STMTENDRQ(bankacctfrom=acct, dtstart=dtstart, dtend=dtend)
         trnuid = self.uuid
@@ -748,7 +768,7 @@ class OFXClient:
         dtend: Optional[datetime.datetime] = None,
         inctran: bool = True,
     ) -> CCSTMTTRNRQ:
-        """ Construct CCSTMTRQ; package in CCSTMTTRNRQ """
+        """Construct CCSTMTRQ; package in CCSTMTTRNRQ"""
         acct = CCACCTFROM(acctid=acctid)
         inctran_ = INCTRAN(dtstart=dtstart, dtend=dtend, include=inctran)
         stmtrq = CCSTMTRQ(ccacctfrom=acct, inctran=inctran_)
@@ -761,7 +781,7 @@ class OFXClient:
         dtstart: Optional[datetime.datetime] = None,
         dtend: Optional[datetime.datetime] = None,
     ) -> CCSTMTENDTRNRQ:
-        """ Construct CCSTMTENDRQ; package in CCSTMTENDTRNRQ """
+        """Construct CCSTMTENDRQ; package in CCSTMTENDTRNRQ"""
         acct = CCACCTFROM(acctid=acctid)
         stmtrq = CCSTMTENDRQ(ccacctfrom=acct, dtstart=dtstart, dtend=dtend)
         trnuid = self.uuid
@@ -779,7 +799,7 @@ class OFXClient:
         incpos: bool = True,
         incbal: bool = True,
     ) -> INVSTMTTRNRQ:
-        """ Construct INVSTMTRQ; package in INVSTMTTRNRQ """
+        """Construct INVSTMTRQ; package in INVSTMTTRNRQ"""
         acct = INVACCTFROM(acctid=acctid, brokerid=brokerid)
         if inctran:
             inctran_: Optional[INCTRAN] = INCTRAN(
@@ -843,25 +863,47 @@ class OFXClient:
         if url is None:
             url = self.url
 
-        req = urllib_request.Request(
-            url, method="POST", data=request, headers=self.http_headers
-        )
+        # NB: we resolve the url opener here instead of in __init__ because the tests
+        #     mock urlopen after instantiating the OFXClient object
+        response = self.post_request(url, request, timeout)
+        return BytesIO(response)
 
+    def post_request(
+        self, url: str, serialized_request: bytes, timeout: Optional[float]
+    ) -> bytes:
+        """Separated out to facilitate mocking in unit tests."""
         if timeout in (None, False):
             #  timeout = socket._GLOBAL_DEFAULT_TIMEOUT  # type: ignore
             timeout = 10.0
 
-        kwargs = dict(timeout=timeout)
+        if USE_REQUESTS:
+            logger.info("Using requests lib to post request")
+            with requests.Session() as sess:
+                if self.persist_cookies:
+                    sess.cookies = self.cookiejar  # type: ignore
 
-        url_opener = self.url_opener
-        if url_opener is None:
-            # NB: we resolve the default url opener here instead
-            #     instead of in __init__ because the tests
-            #     mock urlopen after instantiating the OFXClient object
-            url_opener = urllib_request.urlopen
+                response = sess.request(
+                    method="POST",
+                    url=url,
+                    headers=self.http_headers,
+                    data=serialized_request,
+                    timeout=timeout,
+                )
+            return response.content
 
-        response = url_opener(req, **kwargs)
-        return BytesIO(response.read())
+        else:
+            logger.info("Using urllib to post request")
+            handlers = []
+            if self.persist_cookies:
+                handlers.append(urllib_request.HTTPCookieProcessor(self.cookiejar))
+            opener = urllib_request.build_opener(*handlers)
+
+            req = urllib_request.Request(
+                url, method="POST", data=serialized_request, headers=self.http_headers
+            )
+
+            response = opener.open(req, timeout=timeout)
+            return response.read()  # type: ignore
 
     def serialize(
         self,
