@@ -36,7 +36,6 @@ import logging
 
 
 # local imports
-from ofxtools import config
 from ofxtools.header import parse_header, OFXHeaderType
 from ofxtools.models.base import Aggregate
 
@@ -45,9 +44,7 @@ logger = logging.getLogger(__name__)
 
 
 class ParseError(SyntaxError):
-    """ Exception raised by parsing errors in this module """
-
-    pass
+    """Exception raised by parsing errors in this module"""
 
 
 class OFXTree(ET.ElementTree):
@@ -146,7 +143,7 @@ class TreeBuilder(ET.TreeBuilder):
     # and optionally an end tag (not mandatory for OFXv1 syntax).
     regex = re.compile(
         r"""<(?P<tag>[A-Z0-9./_ ]+?)>
-                (?P<text>[^<]+)?
+                ((<!\[CDATA\[(?P<cdata>.+)\]\]>)|(?P<text>[^<]+))?
             (</(?P<closetag>(?P=tag))>)?
             (?P<tail>[^<]+)?
         """,
@@ -167,7 +164,13 @@ class TreeBuilder(ET.TreeBuilder):
                     raise ParseError(f"Tail text '{tail}' in {match.string}")
 
                 tag = groupdict["tag"]
+
+                # Cf. discussion of element values including CDATA in issue #141
+                cdata = groupdict["cdata"]
                 text = self._groomstring(groupdict["text"])
+                assert not (cdata and text)  # FIXME - can we in fact have both?
+                text = cdata or text
+
                 closetag = groupdict["closetag"]
                 logger.debug(
                     f"Regex match tag='{tag}', text='{text}', closetag='{closetag}'"
@@ -222,7 +225,7 @@ class TreeBuilder(ET.TreeBuilder):
 
     @staticmethod
     def _groomstring(string: str) -> Optional[str]:
-        """ Strips whitespace and returns None for empty string """
+        """Strips whitespace and returns None for empty string"""
         # Can't strip() None
         string = (string or "").strip()
         if string:
@@ -235,10 +238,12 @@ def main(*files):
     Simple functional test for impatient developers.
     """
     for file in files:
+        print(f"Parsing {file}..")
         ofxparser = OFXTree()
         ofxparser.parse(file)
         response = ofxparser.convert()
-        print(response.statements[0].transactions[:])
+        print(response)
+        print("=" * 79)
 
 
 LOG_LEVELS = {0: logging.WARN, 1: logging.INFO, 2: logging.DEBUG}
@@ -247,6 +252,8 @@ LOG_LEVELS = {0: logging.WARN, 1: logging.INFO, 2: logging.DEBUG}
 if __name__ == "__main__":
     from argparse import ArgumentParser
 
+    from ofxtools import config
+
     argparser = ArgumentParser(description="Parse OFX data; dump transactions")
     argparser.add_argument("file", nargs="+", help="OFX file(s)")
     argparser.add_argument(
