@@ -113,7 +113,7 @@ class UuidAction(argparse.Action):
     """
 
     def __call__(self, parser, namespace, values, option_string=None):
-        uuid = OFXClient.uuid
+        uuid = values if values else OFXClient.uuid
         setattr(namespace, self.dest, uuid)
 
 
@@ -221,6 +221,12 @@ def add_subparser(
             dest="useragent",
             help="Value to use in HTTP 'User-Agent' header (defaults to 'InetClntApp/3.0')",
         )
+        parser.add_argument(
+            "--skipprofile",
+            action="store_true",
+            default=None,
+            help="Skip sending PROFRQ to look up service URLs",
+        )
 
     if format:
         parser.add_argument(
@@ -299,10 +305,11 @@ def add_signon_group(parser: argparse.ArgumentParser) -> argparse._ArgumentGroup
     )
     group.add_argument(
         "--clientuid",
-        nargs=0,
+        nargs="?",
         action=UuidAction,
         metavar="UUID4",
-        help="Override default CLIENTUID with random number",
+        help="Override default CLIENTUID with the specified ID, or with a random ID if "
+        "left unspecified",
     )
     group.add_argument("--org", help="FI.ORG")
     group.add_argument("--fid", help="FI.FID")
@@ -619,6 +626,7 @@ def _request_acctinfo(args: ArgsType, password: str) -> BytesIO:
         dtacctup,
         dryrun=args["dryrun"],
         gen_newfileuid=not args["nonewfileuid"],
+        skip_profile=args["skipprofile"],
     ) as f:
         response = f.read()
 
@@ -646,7 +654,7 @@ def _merge_acctinfo(args: ArgsType, markup: BytesIO) -> None:
     ]
 
     # Insert extracted ACCTINFO after CLI commands, but before config files
-    args.maps.insert(1, ChainMap(*parsed_args))
+    args.maps.insert(1, ChainMap(*parsed_args))  # type: ignore
 
 
 def request_stmt(args: ArgsType) -> None:
@@ -717,6 +725,7 @@ def request_stmt(args: ArgsType) -> None:
         *stmtrqs,
         dryrun=args["dryrun"],
         gen_newfileuid=not args["nonewfileuid"],
+        skip_profile=args["skipprofile"],
     ) as f:
         response = f.read()
 
@@ -771,6 +780,7 @@ def request_stmtend(args: ArgsType) -> None:
         *stmtendrqs,
         dryrun=args["dryrun"],
         gen_newfileuid=not args["nonewfileuid"],
+        skip_profile=args["skipprofile"],
     ) as f:
         response = f.read()
 
@@ -798,6 +808,7 @@ def request_tax1099(args: ArgsType) -> None:
         recid=args["recid"],
         dryrun=args["dryrun"],
         gen_newfileuid=not args["nonewfileuid"],
+        skip_profile=args["skipprofile"],
     ) as f:
         response = f.read()
 
@@ -877,6 +888,7 @@ DEFAULTS: Dict[str, ArgType] = {
     "nokeyring": False,
     "nonewfileuid": False,
     "useragent": "",
+    "skipprofile": False,
 }
 
 
@@ -905,6 +917,7 @@ configurable_srvr = (
     "language",
     "nonewfileuid",
     "useragent",
+    "skipprofile",
 )
 CONFIGURABLE_SRVR = {k: type(v) for k, v in DEFAULTS.items() if k in configurable_srvr}
 
@@ -960,6 +973,7 @@ def write_config(args: ArgsType) -> None:
     mk_server_cfg(args)
     logger.info(f"Writing user configs to {USERCONFIGPATH}")
 
+    config.USERCONFIGDIR.mkdir(parents=True, exist_ok=True)
     with open(USERCONFIGPATH, "w") as f:
         USERCFG.write(f)
 
@@ -998,7 +1012,7 @@ def mk_server_cfg(args: ArgsType) -> configparser.SectionProxy:
     lib_cfg = read_config(LIBCFG, server)
 
     def test_cfg_val(opt: str, value: ArgType) -> bool:
-        """ Select CLI args to write to config file """
+        """Select CLI args to write to config file"""
         if value in NULL_ARGS:
             return False
         # Don't include CLIENTUID in the server section if it's sourced
@@ -1064,7 +1078,7 @@ def merge_config(
     else:
         user_cfg = {}
     logger.debug(f"Configs: {user_cfg}")
-    merged: ArgsType = ChainMap(_args, user_cfg, DEFAULTS)
+    merged: ArgsType = ChainMap(_args, user_cfg, DEFAULTS)  # type: ignore
     #  logger.debug(f"CLI args merged with user configs and defaults: {extrargs(merged)}")
 
     # Try to perform an OFX Home lookup if:
@@ -1127,12 +1141,12 @@ def merge_from_ofxhome(args: ArgsType):
 
 
 def extrargs(args: ArgsType) -> dict:
-    """ Extract non-null args """
+    """Extract non-null args"""
     return {k: v for k, v in args.items() if v not in NULL_ARGS}
 
 
 def extractns(ns) -> dict:
-    """ Extract non-null argparse.Namespace"""
+    """Extract non-null argparse.Namespace"""
     return {k: v for k, v in vars(ns).items() if v is not None}
 
 
@@ -1481,7 +1495,7 @@ def list_fis(args: ArgsType) -> None:
 
 
 def fi_index() -> Sequence[Tuple[str, str, str]]:
-    """ All FIs known to ofxget """
+    """All FIs known to ofxget"""
     names = {id_: name for id_, name in USERCFG["NAMES"].items()}
     cfg_default_sect = USERCFG.default_section  # type: ignore
     servers = [
@@ -1501,7 +1515,7 @@ def fi_index() -> Sequence[Tuple[str, str, str]]:
 
 
 def convert_datetime(args: ArgsType) -> Mapping[str, Optional[datetime.datetime]]:
-    """ Convert dtstart/dtend/dtasof to Python datetime type for request """
+    """Convert dtstart/dtend/dtasof to Python datetime type for request"""
     D = DateTime().convert
     return {d[2:]: D(args[d] or None) for d in ("dtstart", "dtend", "dtasof")}
 
